find_kernel_with_idt

Function find_kernel_with_idt 

pub fn find_kernel_with_idt(
    processor: *mut ConfObject,
    build: u32,
) -> Result<u64>
Search for the ntos kernel by using the IDT to determine scan ranges, given a build number